Class: PDFGeneratorAPI::Component
- Inherits:
-
Object
- Object
- PDFGeneratorAPI::Component
- Defined in:
- lib/pdf_generator_api_client/models/component.rb
Overview
Template component definition
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#cls ⇒ Object
Defines component class/type.
-
#data_index ⇒ Object
Defines data field for Table and Container components which are used to iterate over list of items.
-
#height ⇒ Object
Height in units.
-
#id ⇒ Object
Component id.
-
#left ⇒ Object
Position from the page left in units.
-
#top ⇒ Object
Position from the page top in units.
-
#value ⇒ Object
Component value.
-
#width ⇒ Object
Width in units.
-
#zindex ⇒ Object
Defines the rendering order on page.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Component
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Component
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PDFGeneratorAPI::Component` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PDFGeneratorAPI::Component`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'cls') self.cls = attributes[:'cls'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'width') self.width = attributes[:'width'] end if attributes.key?(:'height') self.height = attributes[:'height'] end if attributes.key?(:'top') self.top = attributes[:'top'] end if attributes.key?(:'left') self.left = attributes[:'left'] end if attributes.key?(:'zindex') self.zindex = attributes[:'zindex'] end if attributes.key?(:'value') self.value = attributes[:'value'] end if attributes.key?(:'data_index') self.data_index = attributes[:'data_index'] end end |
Instance Attribute Details
#cls ⇒ Object
Defines component class/type
20 21 22 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 20 def cls @cls end |
#data_index ⇒ Object
Defines data field for Table and Container components which are used to iterate over list of items
44 45 46 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 44 def data_index @data_index end |
#height ⇒ Object
Height in units
29 30 31 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 29 def height @height end |
#id ⇒ Object
Component id
23 24 25 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 23 def id @id end |
#left ⇒ Object
Position from the page left in units
35 36 37 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 35 def left @left end |
#top ⇒ Object
Position from the page top in units
32 33 34 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 32 def top @top end |
#value ⇒ Object
Component value
41 42 43 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 41 def value @value end |
#width ⇒ Object
Width in units
26 27 28 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 26 def width @width end |
#zindex ⇒ Object
Defines the rendering order on page. Components with smaller zindex are rendered before
38 39 40 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 38 def zindex @zindex end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 249 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PDFGeneratorAPI.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
84 85 86 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 84 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
89 90 91 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 89 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 69 def self.attribute_map { :'cls' => :'cls', :'id' => :'id', :'width' => :'width', :'height' => :'height', :'top' => :'top', :'left' => :'left', :'zindex' => :'zindex', :'value' => :'value', :'data_index' => :'dataIndex' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 225 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
109 110 111 112 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 109 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 94 def self.openapi_types { :'cls' => :'String', :'id' => :'String', :'width' => :'Float', :'height' => :'Float', :'top' => :'Float', :'left' => :'Float', :'zindex' => :'Integer', :'value' => :'String', :'data_index' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 196 def ==(o) return true if self.equal?(o) self.class == o.class && cls == o.cls && id == o.id && width == o.width && height == o.height && top == o.top && left == o.left && zindex == o.zindex && value == o.value && data_index == o.data_index end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 320 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
212 213 214 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 212 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
218 219 220 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 218 def hash [cls, id, width, height, top, left, zindex, value, data_index].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
169 170 171 172 173 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 169 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
296 297 298 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 296 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 302 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
290 291 292 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 290 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
177 178 179 180 181 182 |
# File 'lib/pdf_generator_api_client/models/component.rb', line 177 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' cls_validator = EnumAttributeValidator.new('String', ["labelComponent", "textComponent", "dateComponent", "numberComponent", "htmlblockComponent", "tableComponent", "compositeComponent", "chartComponent", "barcodeComponent", "qrcodeComponent", "imageComponent", "headerComponent", "footerComponent", "rectangleComponent", "vlineComponent", "hlineComponent", "pagenumberComponent", "symbolComponent", "checkboxComponent", "radioComponent", "signatureComponent"]) return false unless cls_validator.valid?(@cls) true end |