Class: PDFGeneratorAPI::ConvertPDF2ImageRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ConvertPDF2ImageRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PDFGeneratorAPI::ConvertPDF2ImageRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PDFGeneratorAPI::ConvertPDF2ImageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'file_base64')
    self.file_base64 = attributes[:'file_base64']
  end

  if attributes.key?(:'file_url')
    self.file_url = attributes[:'file_url']
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  else
    self.format = 'png'
  end

  if attributes.key?(:'quality')
    self.quality = attributes[:'quality']
  else
    self.quality = 85
  end

  if attributes.key?(:'resolution')
    self.resolution = attributes[:'resolution']
  else
    self.resolution = 150
  end

  if attributes.key?(:'pages')
    self.pages = attributes[:'pages']
  else
    self.pages = 'all'
  end

  if attributes.key?(:'output')
    self.output = attributes[:'output']
  else
    self.output = 'base64'
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end
end

Instance Attribute Details

#file_base64Object

Base64 encoded PDF file. Required if file_url is not provided.



19
20
21
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 19

def file_base64
  @file_base64
end

#file_urlObject

Public HTTPS URL to a PDF file. Required if file_base64 is not provided.



22
23
24
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 22

def file_url
  @file_url
end

#formatObject

Output image format



25
26
27
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 25

def format
  @format
end

#nameObject

Document name (max 120 characters). Auto-generated if not provided.



40
41
42
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 40

def name
  @name
end

#outputObject

Output format



37
38
39
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 37

def output
  @output
end

#pagesObject

Page number or range to convert. Use a single number (e.g. "1") or a range (e.g. "1-4"). Defaults to all pages.



34
35
36
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 34

def pages
  @pages
end

#qualityObject

Image quality (1-100)



28
29
30
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 28

def quality
  @quality
end

#resolutionObject

Image resolution in DPI (72-600)



31
32
33
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 31

def resolution
  @resolution
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 335

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PDFGeneratorAPI.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 65

def self.attribute_map
  {
    :'file_base64' => :'file_base64',
    :'file_url' => :'file_url',
    :'format' => :'format',
    :'quality' => :'quality',
    :'resolution' => :'resolution',
    :'pages' => :'pages',
    :'output' => :'output',
    :'name' => :'name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 311

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 89

def self.openapi_types
  {
    :'file_base64' => :'String',
    :'file_url' => :'String',
    :'format' => :'String',
    :'quality' => :'Integer',
    :'resolution' => :'Integer',
    :'pages' => :'String',
    :'output' => :'String',
    :'name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 283

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      file_base64 == o.file_base64 &&
      file_url == o.file_url &&
      format == o.format &&
      quality == o.quality &&
      resolution == o.resolution &&
      pages == o.pages &&
      output == o.output &&
      name == o.name
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 406

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 298

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



304
305
306
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 304

def hash
  [file_base64, file_url, format, quality, resolution, pages, output, name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 169

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@quality.nil? && @quality > 100
    invalid_properties.push('invalid value for "quality", must be smaller than or equal to 100.')
  end

  if !@quality.nil? && @quality < 1
    invalid_properties.push('invalid value for "quality", must be greater than or equal to 1.')
  end

  if !@resolution.nil? && @resolution > 600
    invalid_properties.push('invalid value for "resolution", must be smaller than or equal to 600.')
  end

  if !@resolution.nil? && @resolution < 72
    invalid_properties.push('invalid value for "resolution", must be greater than or equal to 72.')
  end

  if !@name.nil? && @name.to_s.length > 120
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 120.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



382
383
384
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 382

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 388

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



376
377
378
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 376

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/pdf_generator_api_client/models/convert_pdf2_image_request.rb', line 197

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  format_validator = EnumAttributeValidator.new('String', ["png", "jpeg", "jpg"])
  return false unless format_validator.valid?(@format)
  return false if !@quality.nil? && @quality > 100
  return false if !@quality.nil? && @quality < 1
  return false if !@resolution.nil? && @resolution > 600
  return false if !@resolution.nil? && @resolution < 72
  output_validator = EnumAttributeValidator.new('String', ["base64", "file"])
  return false unless output_validator.valid?(@output)
  return false if !@name.nil? && @name.to_s.length > 120
  true
end