Class: PDFGeneratorAPI::EInvoicesApi
- Inherits:
-
Object
- Object
- PDFGeneratorAPI::EInvoicesApi
- Defined in:
- lib/pdf_generator_api_client/api/e_invoices_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_e_invoice(create_e_invoice_request, opts = {}) ⇒ InlineObject
Create eInvoice This endpoint transforms a JSON payload into an XML-based e-invoice that is fully compliant with the European EN 16931 standard.
-
#create_e_invoice_with_http_info(create_e_invoice_request, opts = {}) ⇒ Array<(InlineObject, Integer, Hash)>
Create eInvoice This endpoint transforms a JSON payload into an XML-based e-invoice that is fully compliant with the European EN 16931 standard.
-
#create_factur_xe_invoice(create_factur_xe_invoice_request, opts = {}) ⇒ InlineObject9
Create Factur-X eInvoice This endpoint transforms a JSON payload a Factur-X e-invoice that is fully compliant with the European EN 16931 standard.
-
#create_factur_xe_invoice_with_http_info(create_factur_xe_invoice_request, opts = {}) ⇒ Array<(InlineObject9, Integer, Hash)>
Create Factur-X eInvoice This endpoint transforms a JSON payload a Factur-X e-invoice that is fully compliant with the European EN 16931 standard.
-
#create_x_rechnung_e_invoice(create_e_invoice_request, opts = {}) ⇒ InlineObject
Create XRechnung eInvoice This endpoint transforms a JSON payload into an XML-based XRechnung e-invoice that is fully compliant with the European EN 16931 standard.
-
#create_x_rechnung_e_invoice_with_http_info(create_e_invoice_request, opts = {}) ⇒ Array<(InlineObject, Integer, Hash)>
Create XRechnung eInvoice This endpoint transforms a JSON payload into an XML-based XRechnung e-invoice that is fully compliant with the European EN 16931 standard.
-
#get_e_invoice_schema(opts = {}) ⇒ Object
Get schema Returns e-invoice JSON schema which defines the structure of the e-invoice.
-
#get_e_invoice_schema_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get schema Returns e-invoice JSON schema which defines the structure of the e-invoice.
-
#initialize(api_client = ApiClient.default) ⇒ EInvoicesApi
constructor
A new instance of EInvoicesApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ EInvoicesApi
Returns a new instance of EInvoicesApi.
19 20 21 |
# File 'lib/pdf_generator_api_client/api/e_invoices_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pdf_generator_api_client/api/e_invoices_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_e_invoice(create_e_invoice_request, opts = {}) ⇒ InlineObject
Create eInvoice This endpoint transforms a JSON payload into an XML-based e-invoice that is fully compliant with the European EN 16931 standard. The generated output can be formatted in either UBL (Universal Business Language) or CII (Cross-Industry Invoice) syntax, ensuring interoperability across B2B and B2G platforms. The JSON payload follows Peppol BIS Billing 3.0 UBL Invoice described here: docs.peppol.eu/poacc/billing/3.0/
27 28 29 30 |
# File 'lib/pdf_generator_api_client/api/e_invoices_api.rb', line 27 def create_e_invoice(create_e_invoice_request, opts = {}) data, _status_code, _headers = create_e_invoice_with_http_info(create_e_invoice_request, opts) data end |
#create_e_invoice_with_http_info(create_e_invoice_request, opts = {}) ⇒ Array<(InlineObject, Integer, Hash)>
Create eInvoice This endpoint transforms a JSON payload into an XML-based e-invoice that is fully compliant with the European EN 16931 standard. The generated output can be formatted in either UBL (Universal Business Language) or CII (Cross-Industry Invoice) syntax, ensuring interoperability across B2B and B2G platforms. The JSON payload follows Peppol BIS Billing 3.0 UBL Invoice described here: docs.peppol.eu/poacc/billing/3.0/
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/pdf_generator_api_client/api/e_invoices_api.rb', line 37 def create_e_invoice_with_http_info(create_e_invoice_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EInvoicesApi.create_e_invoice ...' end # verify the required parameter 'create_e_invoice_request' is set if @api_client.config.client_side_validation && create_e_invoice_request.nil? fail ArgumentError, "Missing the required parameter 'create_e_invoice_request' when calling EInvoicesApi.create_e_invoice" end # resource path local_var_path = '/einvoice' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_e_invoice_request) # return_type return_type = opts[:debug_return_type] || 'InlineObject' # auth_names auth_names = opts[:debug_auth_names] || ['JSONWebTokenAuth'] = opts.merge( :operation => :"EInvoicesApi.create_e_invoice", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EInvoicesApi#create_e_invoice\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_factur_xe_invoice(create_factur_xe_invoice_request, opts = {}) ⇒ InlineObject9
Create Factur-X eInvoice This endpoint transforms a JSON payload a Factur-X e-invoice that is fully compliant with the European EN 16931 standard. The generated output is always a PDF document, embedding a structured CII (Cross-Industry Invoice) XML according to the Factur-X format into a human-readable invoice, ensuring interoperability across B2B and B2G platforms. The JSON payload follows Peppol BIS Billing 3.0 UBL Invoice described here: docs.peppol.eu/poacc/billing/3.0/
95 96 97 98 |
# File 'lib/pdf_generator_api_client/api/e_invoices_api.rb', line 95 def create_factur_xe_invoice(create_factur_xe_invoice_request, opts = {}) data, _status_code, _headers = create_factur_xe_invoice_with_http_info(create_factur_xe_invoice_request, opts) data end |
#create_factur_xe_invoice_with_http_info(create_factur_xe_invoice_request, opts = {}) ⇒ Array<(InlineObject9, Integer, Hash)>
Create Factur-X eInvoice This endpoint transforms a JSON payload a Factur-X e-invoice that is fully compliant with the European EN 16931 standard. The generated output is always a PDF document, embedding a structured CII (Cross-Industry Invoice) XML according to the Factur-X format into a human-readable invoice, ensuring interoperability across B2B and B2G platforms. The JSON payload follows Peppol BIS Billing 3.0 UBL Invoice described here: docs.peppol.eu/poacc/billing/3.0/
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/pdf_generator_api_client/api/e_invoices_api.rb', line 105 def create_factur_xe_invoice_with_http_info(create_factur_xe_invoice_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EInvoicesApi.create_factur_xe_invoice ...' end # verify the required parameter 'create_factur_xe_invoice_request' is set if @api_client.config.client_side_validation && create_factur_xe_invoice_request.nil? fail ArgumentError, "Missing the required parameter 'create_factur_xe_invoice_request' when calling EInvoicesApi.create_factur_xe_invoice" end # resource path local_var_path = '/einvoice/facturx' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_factur_xe_invoice_request) # return_type return_type = opts[:debug_return_type] || 'InlineObject9' # auth_names auth_names = opts[:debug_auth_names] || ['JSONWebTokenAuth'] = opts.merge( :operation => :"EInvoicesApi.create_factur_xe_invoice", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EInvoicesApi#create_factur_xe_invoice\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_x_rechnung_e_invoice(create_e_invoice_request, opts = {}) ⇒ InlineObject
Create XRechnung eInvoice This endpoint transforms a JSON payload into an XML-based XRechnung e-invoice that is fully compliant with the European EN 16931 standard. The generated output follows the XRechnung format and can be formatted in either UBL (Universal Business Language) or CII (Cross-Industry Invoice) syntax, ensuring interoperability across B2B and B2G platforms. The JSON payload follows Peppol BIS Billing 3.0 UBL Invoice described here: docs.peppol.eu/poacc/billing/3.0/
163 164 165 166 |
# File 'lib/pdf_generator_api_client/api/e_invoices_api.rb', line 163 def create_x_rechnung_e_invoice(create_e_invoice_request, opts = {}) data, _status_code, _headers = create_x_rechnung_e_invoice_with_http_info(create_e_invoice_request, opts) data end |
#create_x_rechnung_e_invoice_with_http_info(create_e_invoice_request, opts = {}) ⇒ Array<(InlineObject, Integer, Hash)>
Create XRechnung eInvoice This endpoint transforms a JSON payload into an XML-based XRechnung e-invoice that is fully compliant with the European EN 16931 standard. The generated output follows the XRechnung format and can be formatted in either UBL (Universal Business Language) or CII (Cross-Industry Invoice) syntax, ensuring interoperability across B2B and B2G platforms. The JSON payload follows Peppol BIS Billing 3.0 UBL Invoice described here: docs.peppol.eu/poacc/billing/3.0/
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/pdf_generator_api_client/api/e_invoices_api.rb', line 173 def create_x_rechnung_e_invoice_with_http_info(create_e_invoice_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EInvoicesApi.create_x_rechnung_e_invoice ...' end # verify the required parameter 'create_e_invoice_request' is set if @api_client.config.client_side_validation && create_e_invoice_request.nil? fail ArgumentError, "Missing the required parameter 'create_e_invoice_request' when calling EInvoicesApi.create_x_rechnung_e_invoice" end # resource path local_var_path = '/einvoice/xrechnung' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_e_invoice_request) # return_type return_type = opts[:debug_return_type] || 'InlineObject' # auth_names auth_names = opts[:debug_auth_names] || ['JSONWebTokenAuth'] = opts.merge( :operation => :"EInvoicesApi.create_x_rechnung_e_invoice", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EInvoicesApi#create_x_rechnung_e_invoice\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_e_invoice_schema(opts = {}) ⇒ Object
Get schema Returns e-invoice JSON schema which defines the structure of the e-invoice.
230 231 232 233 |
# File 'lib/pdf_generator_api_client/api/e_invoices_api.rb', line 230 def get_e_invoice_schema(opts = {}) data, _status_code, _headers = get_e_invoice_schema_with_http_info(opts) data end |
#get_e_invoice_schema_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get schema Returns e-invoice JSON schema which defines the structure of the e-invoice.
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/pdf_generator_api_client/api/e_invoices_api.rb', line 239 def get_e_invoice_schema_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EInvoicesApi.get_e_invoice_schema ...' end # resource path local_var_path = '/einvoice/schema' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['JSONWebTokenAuth'] = opts.merge( :operation => :"EInvoicesApi.get_e_invoice_schema", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EInvoicesApi#get_e_invoice_schema\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |