Class: PDFGeneratorAPI::PrefillParam
- Inherits:
-
Object
- Object
- PDFGeneratorAPI::PrefillParam
- Defined in:
- lib/pdf_generator_api_client/models/prefill_param.rb
Overview
Viewer prefill data, encrypted into the viewer URL. Only applied when output is viewer.
Instance Attribute Summary collapse
-
#editable ⇒ Object
Returns the value of attribute editable.
-
#email ⇒ Object
Returns the value of attribute email.
-
#first_name ⇒ Object
Returns the value of attribute first_name.
-
#id_code ⇒ Object
Returns the value of attribute id_code.
-
#last_name ⇒ Object
Returns the value of attribute last_name.
-
#signature_id ⇒ Object
Returns the value of attribute signature_id.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PrefillParam
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PrefillParam
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PDFGeneratorAPI::PrefillParam` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PDFGeneratorAPI::PrefillParam`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id_code') self.id_code = attributes[:'id_code'] end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'signature_id') self.signature_id = attributes[:'signature_id'] end if attributes.key?(:'editable') self.editable = attributes[:'editable'] else self.editable = true end end |
Instance Attribute Details
#editable ⇒ Object
Returns the value of attribute editable.
29 30 31 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 29 def editable @editable end |
#email ⇒ Object
Returns the value of attribute email.
25 26 27 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 25 def email @email end |
#first_name ⇒ Object
Returns the value of attribute first_name.
21 22 23 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 21 def first_name @first_name end |
#id_code ⇒ Object
Returns the value of attribute id_code.
19 20 21 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 19 def id_code @id_code end |
#last_name ⇒ Object
Returns the value of attribute last_name.
23 24 25 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 23 def last_name @last_name end |
#signature_id ⇒ Object
Returns the value of attribute signature_id.
27 28 29 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 27 def signature_id @signature_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 276 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PDFGeneratorAPI.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 32 def self.attribute_map { :'id_code' => :'id_code', :'first_name' => :'first_name', :'last_name' => :'last_name', :'email' => :'email', :'signature_id' => :'signature_id', :'editable' => :'editable' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 252 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 54 def self.openapi_types { :'id_code' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'email' => :'String', :'signature_id' => :'String', :'editable' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
226 227 228 229 230 231 232 233 234 235 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 226 def ==(o) return true if self.equal?(o) self.class == o.class && id_code == o.id_code && first_name == o.first_name && last_name == o.last_name && email == o.email && signature_id == o.signature_id && editable == o.editable end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 347 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
239 240 241 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 239 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
245 246 247 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 245 def hash [id_code, first_name, last_name, email, signature_id, editable].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@id_code.nil? && @id_code.to_s.length > 128 invalid_properties.push('invalid value for "id_code", the character length must be smaller than or equal to 128.') end if !@first_name.nil? && @first_name.to_s.length > 128 invalid_properties.push('invalid value for "first_name", the character length must be smaller than or equal to 128.') end if !@last_name.nil? && @last_name.to_s.length > 128 invalid_properties.push('invalid value for "last_name", the character length must be smaller than or equal to 128.') end if !@email.nil? && @email.to_s.length > 120 invalid_properties.push('invalid value for "email", the character length must be smaller than or equal to 120.') end if !@signature_id.nil? && @signature_id.to_s.length > 128 invalid_properties.push('invalid value for "signature_id", the character length must be smaller than or equal to 128.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
323 324 325 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 323 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 329 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
317 318 319 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 317 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
144 145 146 147 148 149 150 151 152 |
# File 'lib/pdf_generator_api_client/models/prefill_param.rb', line 144 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@id_code.nil? && @id_code.to_s.length > 128 return false if !@first_name.nil? && @first_name.to_s.length > 128 return false if !@last_name.nil? && @last_name.to_s.length > 128 return false if !@email.nil? && @email.to_s.length > 120 return false if !@signature_id.nil? && @signature_id.to_s.length > 128 true end |