Class: PDFGeneratorAPI::ServicesApi
- Inherits:
-
Object
- Object
- PDFGeneratorAPI::ServicesApi
- Defined in:
- lib/pdf_generator_api_client/api/services_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#add_watermark(add_watermark_request, opts = {}) ⇒ InlineObject9
Add watermark Adds a text or an image watermark to PDF document from base64 string or a remote URL.
-
#add_watermark_with_http_info(add_watermark_request, opts = {}) ⇒ Array<(InlineObject9, Integer, Hash)>
Add watermark Adds a text or an image watermark to PDF document from base64 string or a remote URL.
-
#decrypt_document(encrypt_document_request, opts = {}) ⇒ InlineObject9
Decrypt document Decrypts an encrypted PDF document from base64 string or a remote URL.
-
#decrypt_document_with_http_info(encrypt_document_request, opts = {}) ⇒ Array<(InlineObject9, Integer, Hash)>
Decrypt document Decrypts an encrypted PDF document from base64 string or a remote URL.
-
#encrypt_document(encrypt_document_request, opts = {}) ⇒ InlineObject9
Encrypt document Encrypts a PDF document from base64 string or a remote URL.
-
#encrypt_document_with_http_info(encrypt_document_request, opts = {}) ⇒ Array<(InlineObject9, Integer, Hash)>
Encrypt document Encrypts a PDF document from base64 string or a remote URL.
-
#extract_form_fields(extract_form_fields_request, opts = {}) ⇒ InlineObject14
Extract form fields Extracts form fields and their metadata from a PDF document using base64 string or a remote URL.
-
#extract_form_fields_with_http_info(extract_form_fields_request, opts = {}) ⇒ Array<(InlineObject14, Integer, Hash)>
Extract form fields Extracts form fields and their metadata from a PDF document using base64 string or a remote URL.
-
#fill_form_fields(fill_form_fields_request, opts = {}) ⇒ InlineObject9
Fill form fields Fills form fields in a PDF document with provided data from base64 string or a remote URL.
-
#fill_form_fields_with_http_info(fill_form_fields_request, opts = {}) ⇒ Array<(InlineObject9, Integer, Hash)>
Fill form fields Fills form fields in a PDF document with provided data from base64 string or a remote URL.
-
#initialize(api_client = ApiClient.default) ⇒ ServicesApi
constructor
A new instance of ServicesApi.
-
#make_accessible(make_accessible_request, opts = {}) ⇒ InlineObject9
Make accessible Tags a PDF document for accessibility from base64 string or a remote URL.
-
#make_accessible_with_http_info(make_accessible_request, opts = {}) ⇒ Array<(InlineObject9, Integer, Hash)>
Make accessible Tags a PDF document for accessibility from base64 string or a remote URL.
-
#optimize_document(optimize_document_request, opts = {}) ⇒ InlineObject12
Optimize document Optimizes the size of a PDF document from base64 string or a remote URL.
-
#optimize_document_with_http_info(optimize_document_request, opts = {}) ⇒ Array<(InlineObject12, Integer, Hash)>
Optimize document Optimizes the size of a PDF document from base64 string or a remote URL.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ServicesApi
Returns a new instance of ServicesApi.
19 20 21 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#add_watermark(add_watermark_request, opts = {}) ⇒ InlineObject9
Add watermark Adds a text or an image watermark to PDF document from base64 string or a remote URL.
27 28 29 30 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 27 def add_watermark(add_watermark_request, opts = {}) data, _status_code, _headers = add_watermark_with_http_info(add_watermark_request, opts) data end |
#add_watermark_with_http_info(add_watermark_request, opts = {}) ⇒ Array<(InlineObject9, Integer, Hash)>
Add watermark Adds a text or an image watermark to PDF document from base64 string or a remote URL.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 37 def add_watermark_with_http_info(add_watermark_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServicesApi.add_watermark ...' end # verify the required parameter 'add_watermark_request' is set if @api_client.config.client_side_validation && add_watermark_request.nil? fail ArgumentError, "Missing the required parameter 'add_watermark_request' when calling ServicesApi.add_watermark" end # resource path local_var_path = '/pdfservices/watermark' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(add_watermark_request) # return_type return_type = opts[:debug_return_type] || 'InlineObject9' # auth_names auth_names = opts[:debug_auth_names] || ['JSONWebTokenAuth'] = opts.merge( :operation => :"ServicesApi.add_watermark", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServicesApi#add_watermark\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#decrypt_document(encrypt_document_request, opts = {}) ⇒ InlineObject9
Decrypt document Decrypts an encrypted PDF document from base64 string or a remote URL.
95 96 97 98 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 95 def decrypt_document(encrypt_document_request, opts = {}) data, _status_code, _headers = decrypt_document_with_http_info(encrypt_document_request, opts) data end |
#decrypt_document_with_http_info(encrypt_document_request, opts = {}) ⇒ Array<(InlineObject9, Integer, Hash)>
Decrypt document Decrypts an encrypted PDF document from base64 string or a remote URL.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 105 def decrypt_document_with_http_info(encrypt_document_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServicesApi.decrypt_document ...' end # verify the required parameter 'encrypt_document_request' is set if @api_client.config.client_side_validation && encrypt_document_request.nil? fail ArgumentError, "Missing the required parameter 'encrypt_document_request' when calling ServicesApi.decrypt_document" end # resource path local_var_path = '/pdfservices/decrypt' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(encrypt_document_request) # return_type return_type = opts[:debug_return_type] || 'InlineObject9' # auth_names auth_names = opts[:debug_auth_names] || ['JSONWebTokenAuth'] = opts.merge( :operation => :"ServicesApi.decrypt_document", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServicesApi#decrypt_document\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#encrypt_document(encrypt_document_request, opts = {}) ⇒ InlineObject9
Encrypt document Encrypts a PDF document from base64 string or a remote URL.
163 164 165 166 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 163 def encrypt_document(encrypt_document_request, opts = {}) data, _status_code, _headers = encrypt_document_with_http_info(encrypt_document_request, opts) data end |
#encrypt_document_with_http_info(encrypt_document_request, opts = {}) ⇒ Array<(InlineObject9, Integer, Hash)>
Encrypt document Encrypts a PDF document from base64 string or a remote URL.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 173 def encrypt_document_with_http_info(encrypt_document_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServicesApi.encrypt_document ...' end # verify the required parameter 'encrypt_document_request' is set if @api_client.config.client_side_validation && encrypt_document_request.nil? fail ArgumentError, "Missing the required parameter 'encrypt_document_request' when calling ServicesApi.encrypt_document" end # resource path local_var_path = '/pdfservices/encrypt' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(encrypt_document_request) # return_type return_type = opts[:debug_return_type] || 'InlineObject9' # auth_names auth_names = opts[:debug_auth_names] || ['JSONWebTokenAuth'] = opts.merge( :operation => :"ServicesApi.encrypt_document", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServicesApi#encrypt_document\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#extract_form_fields(extract_form_fields_request, opts = {}) ⇒ InlineObject14
Extract form fields Extracts form fields and their metadata from a PDF document using base64 string or a remote URL.
231 232 233 234 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 231 def extract_form_fields(extract_form_fields_request, opts = {}) data, _status_code, _headers = extract_form_fields_with_http_info(extract_form_fields_request, opts) data end |
#extract_form_fields_with_http_info(extract_form_fields_request, opts = {}) ⇒ Array<(InlineObject14, Integer, Hash)>
Extract form fields Extracts form fields and their metadata from a PDF document using base64 string or a remote URL.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 241 def extract_form_fields_with_http_info(extract_form_fields_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServicesApi.extract_form_fields ...' end # verify the required parameter 'extract_form_fields_request' is set if @api_client.config.client_side_validation && extract_form_fields_request.nil? fail ArgumentError, "Missing the required parameter 'extract_form_fields_request' when calling ServicesApi.extract_form_fields" end # resource path local_var_path = '/pdfservices/form/fields' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(extract_form_fields_request) # return_type return_type = opts[:debug_return_type] || 'InlineObject14' # auth_names auth_names = opts[:debug_auth_names] || ['JSONWebTokenAuth'] = opts.merge( :operation => :"ServicesApi.extract_form_fields", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServicesApi#extract_form_fields\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#fill_form_fields(fill_form_fields_request, opts = {}) ⇒ InlineObject9
Fill form fields Fills form fields in a PDF document with provided data from base64 string or a remote URL.
299 300 301 302 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 299 def fill_form_fields(fill_form_fields_request, opts = {}) data, _status_code, _headers = fill_form_fields_with_http_info(fill_form_fields_request, opts) data end |
#fill_form_fields_with_http_info(fill_form_fields_request, opts = {}) ⇒ Array<(InlineObject9, Integer, Hash)>
Fill form fields Fills form fields in a PDF document with provided data from base64 string or a remote URL.
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 309 def fill_form_fields_with_http_info(fill_form_fields_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServicesApi.fill_form_fields ...' end # verify the required parameter 'fill_form_fields_request' is set if @api_client.config.client_side_validation && fill_form_fields_request.nil? fail ArgumentError, "Missing the required parameter 'fill_form_fields_request' when calling ServicesApi.fill_form_fields" end # resource path local_var_path = '/pdfservices/form/fill' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(fill_form_fields_request) # return_type return_type = opts[:debug_return_type] || 'InlineObject9' # auth_names auth_names = opts[:debug_auth_names] || ['JSONWebTokenAuth'] = opts.merge( :operation => :"ServicesApi.fill_form_fields", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServicesApi#fill_form_fields\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#make_accessible(make_accessible_request, opts = {}) ⇒ InlineObject9
Make accessible Tags a PDF document for accessibility from base64 string or a remote URL.
367 368 369 370 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 367 def make_accessible(make_accessible_request, opts = {}) data, _status_code, _headers = make_accessible_with_http_info(make_accessible_request, opts) data end |
#make_accessible_with_http_info(make_accessible_request, opts = {}) ⇒ Array<(InlineObject9, Integer, Hash)>
Make accessible Tags a PDF document for accessibility from base64 string or a remote URL.
377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 377 def make_accessible_with_http_info(make_accessible_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServicesApi.make_accessible ...' end # verify the required parameter 'make_accessible_request' is set if @api_client.config.client_side_validation && make_accessible_request.nil? fail ArgumentError, "Missing the required parameter 'make_accessible_request' when calling ServicesApi.make_accessible" end # resource path local_var_path = '/pdfservices/make-accessible' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(make_accessible_request) # return_type return_type = opts[:debug_return_type] || 'InlineObject9' # auth_names auth_names = opts[:debug_auth_names] || ['JSONWebTokenAuth'] = opts.merge( :operation => :"ServicesApi.make_accessible", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServicesApi#make_accessible\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#optimize_document(optimize_document_request, opts = {}) ⇒ InlineObject12
Optimize document Optimizes the size of a PDF document from base64 string or a remote URL.
435 436 437 438 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 435 def optimize_document(optimize_document_request, opts = {}) data, _status_code, _headers = optimize_document_with_http_info(optimize_document_request, opts) data end |
#optimize_document_with_http_info(optimize_document_request, opts = {}) ⇒ Array<(InlineObject12, Integer, Hash)>
Optimize document Optimizes the size of a PDF document from base64 string or a remote URL.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 |
# File 'lib/pdf_generator_api_client/api/services_api.rb', line 445 def optimize_document_with_http_info(optimize_document_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServicesApi.optimize_document ...' end # verify the required parameter 'optimize_document_request' is set if @api_client.config.client_side_validation && optimize_document_request.nil? fail ArgumentError, "Missing the required parameter 'optimize_document_request' when calling ServicesApi.optimize_document" end # resource path local_var_path = '/pdfservices/optimize' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(optimize_document_request) # return_type return_type = opts[:debug_return_type] || 'InlineObject12' # auth_names auth_names = opts[:debug_auth_names] || ['JSONWebTokenAuth'] = opts.merge( :operation => :"ServicesApi.optimize_document", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServicesApi#optimize_document\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |