Class: PDFGeneratorAPI::TemplateLibraryApi
- Inherits:
-
Object
- Object
- PDFGeneratorAPI::TemplateLibraryApi
- Defined in:
- lib/pdf_generator_api_client/api/template_library_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_template_library(opts = {}) ⇒ GetTemplateLibrary200Response
Get template library Returns a list of publicly available templates from the template library.
-
#get_template_library_item(public_id, opts = {}) ⇒ InlineObject16
Open template from the library Returns the template definition for a public template identified by its ‘public_id`.
-
#get_template_library_item_with_http_info(public_id, opts = {}) ⇒ Array<(InlineObject16, Integer, Hash)>
Open template from the library Returns the template definition for a public template identified by its `public_id`.
-
#get_template_library_with_http_info(opts = {}) ⇒ Array<(GetTemplateLibrary200Response, Integer, Hash)>
Get template library Returns a list of publicly available templates from the template library.
-
#initialize(api_client = ApiClient.default) ⇒ TemplateLibraryApi
constructor
A new instance of TemplateLibraryApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TemplateLibraryApi
Returns a new instance of TemplateLibraryApi.
19 20 21 |
# File 'lib/pdf_generator_api_client/api/template_library_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pdf_generator_api_client/api/template_library_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_template_library(opts = {}) ⇒ GetTemplateLibrary200Response
Get template library Returns a list of publicly available templates from the template library.
27 28 29 30 |
# File 'lib/pdf_generator_api_client/api/template_library_api.rb', line 27 def get_template_library(opts = {}) data, _status_code, _headers = get_template_library_with_http_info(opts) data end |
#get_template_library_item(public_id, opts = {}) ⇒ InlineObject16
Open template from the library Returns the template definition for a public template identified by its ‘public_id`.
87 88 89 90 |
# File 'lib/pdf_generator_api_client/api/template_library_api.rb', line 87 def get_template_library_item(public_id, opts = {}) data, _status_code, _headers = get_template_library_item_with_http_info(public_id, opts) data end |
#get_template_library_item_with_http_info(public_id, opts = {}) ⇒ Array<(InlineObject16, Integer, Hash)>
Open template from the library Returns the template definition for a public template identified by its `public_id`.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/pdf_generator_api_client/api/template_library_api.rb', line 97 def get_template_library_item_with_http_info(public_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TemplateLibraryApi.get_template_library_item ...' end # verify the required parameter 'public_id' is set if @api_client.config.client_side_validation && public_id.nil? fail ArgumentError, "Missing the required parameter 'public_id' when calling TemplateLibraryApi.get_template_library_item" end # resource path local_var_path = '/templates/library/{publicId}'.sub('{' + 'publicId' + '}', CGI.escape(public_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'InlineObject16' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"TemplateLibraryApi.get_template_library_item", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TemplateLibraryApi#get_template_library_item\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_template_library_with_http_info(opts = {}) ⇒ Array<(GetTemplateLibrary200Response, Integer, Hash)>
Get template library Returns a list of publicly available templates from the template library.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/pdf_generator_api_client/api/template_library_api.rb', line 37 def get_template_library_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TemplateLibraryApi.get_template_library ...' end # resource path local_var_path = '/templates/library' # query parameters query_params = opts[:query_params] || {} query_params[:'tags'] = opts[:'tags'] if !opts[:'tags'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetTemplateLibrary200Response' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"TemplateLibraryApi.get_template_library", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TemplateLibraryApi#get_template_library\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |