Class: PDFGeneratorAPI::WorkspacesApi
- Inherits:
-
Object
- Object
- PDFGeneratorAPI::WorkspacesApi
- Defined in:
- lib/pdf_generator_api_client/api/workspaces_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_workspace(opts = {}) ⇒ InlineObject8
Create workspace Creates a regular workspace with identifier specified in the request.
-
#create_workspace_with_http_info(opts = {}) ⇒ Array<(InlineObject8, Integer, Hash)>
Create workspace Creates a regular workspace with identifier specified in the request.
-
#delete_workspace(workspace_identifier, opts = {}) ⇒ nil
Delete workspace Delete workspace.
-
#delete_workspace_with_http_info(workspace_identifier, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete workspace Delete workspace.
-
#get_workspace(workspace_identifier, opts = {}) ⇒ InlineObject8
Get workspace Returns workspace information for the workspace identifier specified in the request.
-
#get_workspace_with_http_info(workspace_identifier, opts = {}) ⇒ Array<(InlineObject8, Integer, Hash)>
Get workspace Returns workspace information for the workspace identifier specified in the request.
-
#get_workspaces(opts = {}) ⇒ InlineObject5
Get workspaces Returns all workspaces in the organization.
-
#get_workspaces_with_http_info(opts = {}) ⇒ Array<(InlineObject5, Integer, Hash)>
Get workspaces Returns all workspaces in the organization.
-
#initialize(api_client = ApiClient.default) ⇒ WorkspacesApi
constructor
A new instance of WorkspacesApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WorkspacesApi
Returns a new instance of WorkspacesApi.
19 20 21 |
# File 'lib/pdf_generator_api_client/api/workspaces_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pdf_generator_api_client/api/workspaces_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_workspace(opts = {}) ⇒ InlineObject8
Create workspace Creates a regular workspace with identifier specified in the request.
27 28 29 30 |
# File 'lib/pdf_generator_api_client/api/workspaces_api.rb', line 27 def create_workspace(opts = {}) data, _status_code, _headers = create_workspace_with_http_info(opts) data end |
#create_workspace_with_http_info(opts = {}) ⇒ Array<(InlineObject8, Integer, Hash)>
Create workspace Creates a regular workspace with identifier specified in the request.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/pdf_generator_api_client/api/workspaces_api.rb', line 37 def create_workspace_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkspacesApi.create_workspace ...' end # resource path local_var_path = '/workspaces' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'create_workspace_request']) # return_type return_type = opts[:debug_return_type] || 'InlineObject8' # auth_names auth_names = opts[:debug_auth_names] || ['JSONWebTokenAuth'] = opts.merge( :operation => :"WorkspacesApi.create_workspace", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkspacesApi#create_workspace\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_workspace(workspace_identifier, opts = {}) ⇒ nil
Delete workspace Delete workspace. Only regular workspaces can be deleted.
91 92 93 94 |
# File 'lib/pdf_generator_api_client/api/workspaces_api.rb', line 91 def delete_workspace(workspace_identifier, opts = {}) delete_workspace_with_http_info(workspace_identifier, opts) nil end |
#delete_workspace_with_http_info(workspace_identifier, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete workspace Delete workspace. Only regular workspaces can be deleted.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/pdf_generator_api_client/api/workspaces_api.rb', line 101 def delete_workspace_with_http_info(workspace_identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkspacesApi.delete_workspace ...' end # verify the required parameter 'workspace_identifier' is set if @api_client.config.client_side_validation && workspace_identifier.nil? fail ArgumentError, "Missing the required parameter 'workspace_identifier' when calling WorkspacesApi.delete_workspace" end # resource path local_var_path = '/workspaces/{workspaceIdentifier}'.sub('{' + 'workspaceIdentifier' + '}', CGI.escape(workspace_identifier.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['JSONWebTokenAuth'] = opts.merge( :operation => :"WorkspacesApi.delete_workspace", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkspacesApi#delete_workspace\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_workspace(workspace_identifier, opts = {}) ⇒ InlineObject8
Get workspace Returns workspace information for the workspace identifier specified in the request.
154 155 156 157 |
# File 'lib/pdf_generator_api_client/api/workspaces_api.rb', line 154 def get_workspace(workspace_identifier, opts = {}) data, _status_code, _headers = get_workspace_with_http_info(workspace_identifier, opts) data end |
#get_workspace_with_http_info(workspace_identifier, opts = {}) ⇒ Array<(InlineObject8, Integer, Hash)>
Get workspace Returns workspace information for the workspace identifier specified in the request.
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/pdf_generator_api_client/api/workspaces_api.rb', line 164 def get_workspace_with_http_info(workspace_identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkspacesApi.get_workspace ...' end # verify the required parameter 'workspace_identifier' is set if @api_client.config.client_side_validation && workspace_identifier.nil? fail ArgumentError, "Missing the required parameter 'workspace_identifier' when calling WorkspacesApi.get_workspace" end # resource path local_var_path = '/workspaces/{workspaceIdentifier}'.sub('{' + 'workspaceIdentifier' + '}', CGI.escape(workspace_identifier.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'InlineObject8' # auth_names auth_names = opts[:debug_auth_names] || ['JSONWebTokenAuth'] = opts.merge( :operation => :"WorkspacesApi.get_workspace", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkspacesApi#get_workspace\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_workspaces(opts = {}) ⇒ InlineObject5
Get workspaces Returns all workspaces in the organization
218 219 220 221 |
# File 'lib/pdf_generator_api_client/api/workspaces_api.rb', line 218 def get_workspaces(opts = {}) data, _status_code, _headers = get_workspaces_with_http_info(opts) data end |
#get_workspaces_with_http_info(opts = {}) ⇒ Array<(InlineObject5, Integer, Hash)>
Get workspaces Returns all workspaces in the organization
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/pdf_generator_api_client/api/workspaces_api.rb', line 229 def get_workspaces_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkspacesApi.get_workspaces ...' end # resource path local_var_path = '/workspaces' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'InlineObject5' # auth_names auth_names = opts[:debug_auth_names] || ['JSONWebTokenAuth'] = opts.merge( :operation => :"WorkspacesApi.get_workspaces", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkspacesApi#get_workspaces\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |